@@ -1,4 +1,4 @@
-__version__ = '0.2.3'
+__version__ = '0.2.4'
 import struct
 import binascii
 
@@ -6,11 +6,12 @@ import binascii
 num_bytes = 16
 
 
-def save(uuid, vector: list[float], filename='data.bin'):
+def save(uuid, vector: list, geo: list, filename='data.bin'):
     f = open(filename, 'ab')
     f.write(struct.pack('B'*num_bytes, *uuid))
     data = [struct.pack('d', f) for f in vector]
     [f.write(d) for d in data]
+    [f.write(d) for d in [struct.pack('d', f) for f in geo]]
     f.close()
 
 
